@@ -19,10 +19,10 @@
 
 from qgis.core import QgsApplication, QgsAuthMethodConfig, QgsMessageLog
 
-from modelbaker.db_factory.db_simple_factory import DbSimpleFactory
-from modelbaker.dbconnector.db_connector import DBConnectorError
-from modelbaker.iliwrapper.globals import DbIliMode
-from modelbaker.utils.qt_utils import slugify
+from ..db_factory.db_simple_factory import DbSimpleFactory
+from ..dbconnector.db_connector import DBConnectorError
+from ..iliwrapper.globals import DbIliMode
+from .qt_utils import slugify
 
 
 def get_schema_identificator_from_layersource(layer_source_name, layer_source):
